@@ -14,7 +14,8 @@ __email__ = __email__
 
 
 # Imports
-# Local Libraries #
+# Local Packages #
+from .meta import *
 from .basetimedcache import BaseTimedCache
 from .timedsinglecache import TimedSingleCache
 from .timedkeylesscache import TimedKeylessCache
